
// Fonction pour générer des arbres hiérarchiques à partir des données.
export function generateTree(treeData, treeId, treeLayout) {
const root = d3.hierarchy(treeData);
root.each((node, i) => {
node.id = `${treeId}-${i}`;
node.data.accuracy = node.parent ? node.parent.data.accuracy : treeData.accuracy; 
});
return treeLayout(root);
}

// Fonction pour déterminer la couleur en fonction de l'accuracy.
export function getColorByAccuracy(accuracy) {
if (accuracy >= 0.8) {
    return "red";
} else if (accuracy >= 0.6) {
    return "blue";
} else {
    return "gray";
}
}

//calculer le cercle circonscrit
export function calculateBoundingCircle(tree) {
    const xCoords = tree.descendants().filter(d => d.parent).map(d => d.x);
    const yCoords = tree.descendants().filter(d => d.parent).map(d => d.y);
    const minX = Math.min(...xCoords);
    const maxX = Math.max(...xCoords);
    const minY = Math.min(...yCoords);
    const maxY = Math.max(...yCoords);
    const centerX = (minX + maxX) / 2;
    const centerY = (minY + maxY) / 2;
    const radius = Math.sqrt(Math.pow(maxX - minX, 2) + Math.pow(maxY - minY, 2)) / 2;
    return { centerX, centerY, radius };
  }


// Fonction pour calculer la position X de chaque arbre en fonction de son accuracy
export function calculateTreeXPosition(accuracy, totalWidth) {
    let xPos;
    if (accuracy >= 0.8) {
      xPos = totalWidth / 6;
    } else if (accuracy >= 0.6) {
      xPos = totalWidth / 2;
    } else {
      xPos = (5 * totalWidth) / 6;
    }
    return xPos;
  }
  
  export function setBubble(slider, bubble) {
    let val = slider.value;
    let min = slider.min ? slider.min : 0;
    let max = slider.max ? slider.max : 100;
    let newVal = Number(((val - min) * 100) / (max - min));
    bubble.innerHTML = val;

    // Sorta magic numbers based on size and scale.
    bubble.style.left = `calc(${newVal}% + (${8 - newVal * 0.15}px)